#[repr(C)]pub struct ClockGetRateResponse {
pub hz: u64,
}Fields
hz: u64Trait Implementations
Sourceimpl Clone for ClockGetRateResponse
impl Clone for ClockGetRateResponse
Sourcefn clone(&self) -> ClockGetRateResponse
fn clone(&self) -> ClockGetRateResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClockGetRateResponse
impl Debug for ClockGetRateResponse
Sourceimpl<'a, ___E> Encode<ClockGetRateResponse, ___E> for &'a ClockGetRateResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ClockGetRateResponse, ___E> for &'a ClockGetRateResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetRateResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetRateResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockGetRateResponse, ___E> for ClockGetRateResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ClockGetRateResponse, ___E> for ClockGetRateResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockGetRateResponse, ClockGetRateResponse>
const COPY_OPTIMIZATION: CopyOptimization<ClockGetRateResponse, ClockGetRateResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetRateResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetRateResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ClockGetRateResponse>, ___E> for &'a ClockGetRateResponse
impl<'a, ___E> EncodeOption<Box<'static, ClockGetRateResponse>, ___E> for &'a ClockGetRateResponse
Sourcefn encode_option(
this: Option<&'a ClockGetRateResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockGetRateResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ClockGetRateResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockGetRateResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ClockGetRateResponse>, ___E> for ClockGetRateResponse
impl<___E> EncodeOption<Box<'static, ClockGetRateResponse>, ___E> for ClockGetRateResponse
Sourcefn encode_option(
this: Option<ClockGetRateResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockGetRateResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ClockGetRateResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockGetRateResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ClockGetRateResponse> for ClockGetRateResponse
impl FromWire<ClockGetRateResponse> for ClockGetRateResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockGetRateResponse, ClockGetRateResponse>
const COPY_OPTIMIZATION: CopyOptimization<ClockGetRateResponse, ClockGetRateResponse>
Sourcefn from_wire(wire: ClockGetRateResponse) -> ClockGetRateResponse
fn from_wire(wire: ClockGetRateResponse) -> ClockGetRateResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<ClockGetRateResponse> for ClockGetRateResponse
impl FromWireRef<ClockGetRateResponse> for ClockGetRateResponse
Sourcefn from_wire_ref(wire: &ClockGetRateResponse) -> ClockGetRateResponse
fn from_wire_ref(wire: &ClockGetRateResponse) -> ClockGetRateResponse
Converts the given reference to this type.
Sourceimpl Hash for ClockGetRateResponse
impl Hash for ClockGetRateResponse
Sourceimpl Ord for ClockGetRateResponse
impl Ord for ClockGetRateResponse
Sourcefn cmp(&self, other: &ClockGetRateResponse) -> Ordering
fn cmp(&self, other: &ClockGetRateResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClockGetRateResponse
impl PartialEq for ClockGetRateResponse
Sourcefn eq(&self, other: &ClockGetRateResponse) -> bool
fn eq(&self, other: &ClockGetRateResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClockGetRateResponse
impl PartialOrd for ClockGetRateResponse
impl Copy for ClockGetRateResponse
impl Eq for ClockGetRateResponse
impl StructuralPartialEq for ClockGetRateResponse