#[repr(C)]pub struct ClockQuerySupportedRateRequest {
pub hz_in: u64,
}Fields
hz_in: u64Trait Implementations
Sourceimpl Clone for ClockQuerySupportedRateRequest
impl Clone for ClockQuerySupportedRateRequest
Sourcefn clone(&self) -> ClockQuerySupportedRateRequest
fn clone(&self) -> ClockQuerySupportedRateRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<ClockQuerySupportedRateRequest, ___E> for &'a ClockQuerySupportedRateRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ClockQuerySupportedRateRequest, ___E> for &'a ClockQuerySupportedRateRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockQuerySupportedRateRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockQuerySupportedRateRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockQuerySupportedRateRequest, ___E> for ClockQuerySupportedRateRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ClockQuerySupportedRateRequest, ___E> for ClockQuerySupportedRateRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockQuerySupportedRateRequest, ClockQuerySupportedRateRequest>
const COPY_OPTIMIZATION: CopyOptimization<ClockQuerySupportedRateRequest, ClockQuerySupportedRateRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockQuerySupportedRateRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockQuerySupportedRateRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ClockQuerySupportedRateRequest>, ___E> for &'a ClockQuerySupportedRateRequestwhere
___E: Encoder + ?Sized,
&'a ClockQuerySupportedRateRequest: Encode<ClockQuerySupportedRateRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ClockQuerySupportedRateRequest>, ___E> for &'a ClockQuerySupportedRateRequestwhere
___E: Encoder + ?Sized,
&'a ClockQuerySupportedRateRequest: Encode<ClockQuerySupportedRateRequest, ___E>,
Sourcefn encode_option(
this: Option<&'a ClockQuerySupportedRateRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockQuerySupportedRateRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a ClockQuerySupportedRateRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockQuerySupportedRateRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ClockQuerySupportedRateRequest>, ___E> for ClockQuerySupportedRateRequestwhere
___E: Encoder + ?Sized,
ClockQuerySupportedRateRequest: Encode<ClockQuerySupportedRateRequest, ___E>,
impl<___E> EncodeOption<Box<'static, ClockQuerySupportedRateRequest>, ___E> for ClockQuerySupportedRateRequestwhere
___E: Encoder + ?Sized,
ClockQuerySupportedRateRequest: Encode<ClockQuerySupportedRateRequest, ___E>,
Sourcefn encode_option(
this: Option<ClockQuerySupportedRateRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ClockQuerySupportedRateRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<ClockQuerySupportedRateRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ClockQuerySupportedRateRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ClockQuerySupportedRateRequest> for ClockQuerySupportedRateRequest
impl FromWire<ClockQuerySupportedRateRequest> for ClockQuerySupportedRateRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockQuerySupportedRateRequest, ClockQuerySupportedRateRequest>
const COPY_OPTIMIZATION: CopyOptimization<ClockQuerySupportedRateRequest, ClockQuerySupportedRateRequest>
Sourcefn from_wire(
wire: ClockQuerySupportedRateRequest,
) -> ClockQuerySupportedRateRequest
fn from_wire( wire: ClockQuerySupportedRateRequest, ) -> ClockQuerySupportedRateRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<ClockQuerySupportedRateRequest> for ClockQuerySupportedRateRequest
impl FromWireRef<ClockQuerySupportedRateRequest> for ClockQuerySupportedRateRequest
Sourcefn from_wire_ref(
wire: &ClockQuerySupportedRateRequest,
) -> ClockQuerySupportedRateRequest
fn from_wire_ref( wire: &ClockQuerySupportedRateRequest, ) -> ClockQuerySupportedRateRequest
Converts the given reference to this type.
Sourceimpl Ord for ClockQuerySupportedRateRequest
impl Ord for ClockQuerySupportedRateRequest
Sourcefn cmp(&self, other: &ClockQuerySupportedRateRequest) -> Ordering
fn cmp(&self, other: &ClockQuerySupportedRateRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClockQuerySupportedRateRequest
impl PartialEq for ClockQuerySupportedRateRequest
Sourcefn eq(&self, other: &ClockQuerySupportedRateRequest) -> bool
fn eq(&self, other: &ClockQuerySupportedRateRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClockQuerySupportedRateRequest
impl PartialOrd for ClockQuerySupportedRateRequest
impl Copy for ClockQuerySupportedRateRequest
impl Eq for ClockQuerySupportedRateRequest
impl StructuralPartialEq for ClockQuerySupportedRateRequest