#[repr(C)]pub struct ClockGetNumInputsResponse {
pub n: Uint32,
}Expand description
The wire type corresponding to ClockGetNumInputsResponse.
Fields
n: Uint32Trait Implementations
Sourceimpl Clone for ClockGetNumInputsResponse
impl Clone for ClockGetNumInputsResponse
Sourcefn clone(&self) -> ClockGetNumInputsResponse
fn clone(&self) -> ClockGetNumInputsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ClockGetNumInputsResponse
impl Constrained for ClockGetNumInputsResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, ClockGetNumInputsResponse>,
_: <ClockGetNumInputsResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, ClockGetNumInputsResponse>, _: <ClockGetNumInputsResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for ClockGetNumInputsResponse
impl Debug for ClockGetNumInputsResponse
Sourceimpl<___D> Decode<___D> for ClockGetNumInputsResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ClockGetNumInputsResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ClockGetNumInputsResponse, ___E> for &'a ClockGetNumInputsResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ClockGetNumInputsResponse, ___E> for &'a ClockGetNumInputsResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetNumInputsResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetNumInputsResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockGetNumInputsResponse, ___E> for ClockGetNumInputsResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ClockGetNumInputsResponse, ___E> for ClockGetNumInputsResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockGetNumInputsResponse, ClockGetNumInputsResponse>
const COPY_OPTIMIZATION: CopyOptimization<ClockGetNumInputsResponse, ClockGetNumInputsResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetNumInputsResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetNumInputsResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ClockGetNumInputsResponse, ___E> for ClockGetNumInputsResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<ClockGetNumInputsResponse, ___E> for ClockGetNumInputsResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetNumInputsResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetNumInputsResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ClockGetNumInputsResponse> for ClockGetNumInputsResponse
impl FromWire<ClockGetNumInputsResponse> for ClockGetNumInputsResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockGetNumInputsResponse, ClockGetNumInputsResponse>
const COPY_OPTIMIZATION: CopyOptimization<ClockGetNumInputsResponse, ClockGetNumInputsResponse>
Sourcefn from_wire(wire: ClockGetNumInputsResponse) -> ClockGetNumInputsResponse
fn from_wire(wire: ClockGetNumInputsResponse) -> ClockGetNumInputsResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<ClockGetNumInputsResponse> for ClockGetNumInputsResponse
impl FromWireRef<ClockGetNumInputsResponse> for ClockGetNumInputsResponse
Sourcefn from_wire_ref(wire: &ClockGetNumInputsResponse) -> ClockGetNumInputsResponse
fn from_wire_ref(wire: &ClockGetNumInputsResponse) -> ClockGetNumInputsResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for ClockGetNumInputsResponse
impl IntoNatural for ClockGetNumInputsResponse
Sourcetype Natural = ClockGetNumInputsResponse
type Natural = ClockGetNumInputsResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ClockGetNumInputsResponse
impl Wire for ClockGetNumInputsResponse
Sourcetype Narrowed<'de> = ClockGetNumInputsResponse
type Narrowed<'de> = ClockGetNumInputsResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<ClockGetNumInputsResponse>)
fn zero_padding(out_: &mut MaybeUninit<ClockGetNumInputsResponse>)
Writes zeroes to the padding for this type, if any.