#[repr(C)]pub struct ClockGetRateResponse {
pub hz: Uint64,
}Expand description
The wire type corresponding to ClockGetRateResponse.
Fields
hz: Uint64Trait Implementations
Sourceimpl Clone for ClockGetRateResponse
impl Clone for ClockGetRateResponse
Sourcefn clone(&self) -> ClockGetRateResponse
fn clone(&self) -> ClockGetRateResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ClockGetRateResponse
impl Constrained for ClockGetRateResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, ClockGetRateResponse>,
_: <ClockGetRateResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, ClockGetRateResponse>, _: <ClockGetRateResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for ClockGetRateResponse
impl Debug for ClockGetRateResponse
Sourceimpl<___D> Decode<___D> for ClockGetRateResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ClockGetRateResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ClockGetRateResponse, ___E> for &'a ClockGetRateResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ClockGetRateResponse, ___E> for &'a ClockGetRateResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetRateResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetRateResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockGetRateResponse, ___E> for ClockGetRateResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ClockGetRateResponse, ___E> for ClockGetRateResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockGetRateResponse, ClockGetRateResponse>
const COPY_OPTIMIZATION: CopyOptimization<ClockGetRateResponse, ClockGetRateResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetRateResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetRateResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ClockGetRateResponse, ___E> for ClockGetRateResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
impl<___E, T0> Encode<ClockGetRateResponse, ___E> for ClockGetRateResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockGetRateResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockGetRateResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ClockGetRateResponse> for ClockGetRateResponse
impl FromWire<ClockGetRateResponse> for ClockGetRateResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockGetRateResponse, ClockGetRateResponse>
const COPY_OPTIMIZATION: CopyOptimization<ClockGetRateResponse, ClockGetRateResponse>
Sourcefn from_wire(wire: ClockGetRateResponse) -> ClockGetRateResponse
fn from_wire(wire: ClockGetRateResponse) -> ClockGetRateResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<ClockGetRateResponse> for ClockGetRateResponse
impl FromWireRef<ClockGetRateResponse> for ClockGetRateResponse
Sourcefn from_wire_ref(wire: &ClockGetRateResponse) -> ClockGetRateResponse
fn from_wire_ref(wire: &ClockGetRateResponse) -> ClockGetRateResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for ClockGetRateResponse
impl IntoNatural for ClockGetRateResponse
Sourcetype Natural = ClockGetRateResponse
type Natural = ClockGetRateResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ClockGetRateResponse
impl Wire for ClockGetRateResponse
Sourcetype Narrowed<'de> = ClockGetRateResponse
type Narrowed<'de> = ClockGetRateResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<ClockGetRateResponse>)
fn zero_padding(out_: &mut MaybeUninit<ClockGetRateResponse>)
Writes zeroes to the padding for this type, if any.