#[repr(C)]pub struct ClockSetInputRequest {
pub idx: Uint32,
}Expand description
The wire type corresponding to ClockSetInputRequest.
Fields
idx: Uint32Trait Implementations
Sourceimpl Clone for ClockSetInputRequest
impl Clone for ClockSetInputRequest
Sourcefn clone(&self) -> ClockSetInputRequest
fn clone(&self) -> ClockSetInputRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ClockSetInputRequest
impl Constrained for ClockSetInputRequest
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, ClockSetInputRequest>,
_: <ClockSetInputRequest as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, ClockSetInputRequest>, _: <ClockSetInputRequest as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for ClockSetInputRequest
impl Debug for ClockSetInputRequest
Sourceimpl<___D> Decode<___D> for ClockSetInputRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ClockSetInputRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ClockSetInputRequest, ___E> for &'a ClockSetInputRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ClockSetInputRequest, ___E> for &'a ClockSetInputRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockSetInputRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockSetInputRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ClockSetInputRequest, ___E> for ClockSetInputRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ClockSetInputRequest, ___E> for ClockSetInputRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockSetInputRequest, ClockSetInputRequest>
const COPY_OPTIMIZATION: CopyOptimization<ClockSetInputRequest, ClockSetInputRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockSetInputRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockSetInputRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ClockSetInputRequest, ___E> for ClockSetInputRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
impl<___E, T0> Encode<ClockSetInputRequest, ___E> for ClockSetInputRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ClockSetInputRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ClockSetInputRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ClockSetInputRequest> for ClockSetInputRequest
impl FromWire<ClockSetInputRequest> for ClockSetInputRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ClockSetInputRequest, ClockSetInputRequest>
const COPY_OPTIMIZATION: CopyOptimization<ClockSetInputRequest, ClockSetInputRequest>
Sourcefn from_wire(wire: ClockSetInputRequest) -> ClockSetInputRequest
fn from_wire(wire: ClockSetInputRequest) -> ClockSetInputRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<ClockSetInputRequest> for ClockSetInputRequest
impl FromWireRef<ClockSetInputRequest> for ClockSetInputRequest
Sourcefn from_wire_ref(wire: &ClockSetInputRequest) -> ClockSetInputRequest
fn from_wire_ref(wire: &ClockSetInputRequest) -> ClockSetInputRequest
Converts the given reference to this type.
Sourceimpl IntoNatural for ClockSetInputRequest
impl IntoNatural for ClockSetInputRequest
Sourcetype Natural = ClockSetInputRequest
type Natural = ClockSetInputRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ClockSetInputRequest
impl Wire for ClockSetInputRequest
Sourcetype Narrowed<'de> = ClockSetInputRequest
type Narrowed<'de> = ClockSetInputRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<ClockSetInputRequest>)
fn zero_padding(out_: &mut MaybeUninit<ClockSetInputRequest>)
Writes zeroes to the padding for this type, if any.